| Title: | The liMES R package |
|---|---|
| Description: | Contains the LIMES-specific routines for data and model output manipulation. |
| Authors: | Sebastian Osorio [aut, cre] |
| Maintainer: | Sebastian Osorio <[email protected]> |
| License: | LGPL-3 |
| Version: | 2.81.1 |
| Built: | 2026-06-02 15:05:17 UTC |
| Source: | https://github.com/pik-piam/limes |
Contains the LIMES-specific routines for data and model output manipulation
| Package: | remind |
| Type: | Package |
| Version: | 7.6 |
| Date: | 2017-11-20 |
| License: | LGPL-3 |
| LazyLoad: | yes |
Sebastian Osorio and Renato Rodrigues
Maintainer: Sebastian Osorio <[email protected]>
Renders the *.Rmd-files associated to compareScenariosLimes. In the Rmds, scenario- and historical .mif-files are loaded. Then plots are created from this data. The result may be rendered to PDF or HTML. Alternatively one can choose Rmd as output format and obtain a copy of the *.Rmd-files.
compareScenariosLimes( mifScen, outputDir = getwd(), outputFile = "compareScenariosLimes", outputFormat = "PDF", envir = new.env(), quiet = FALSE, ... )compareScenariosLimes( mifScen, outputDir = getwd(), outputFile = "compareScenariosLimes", outputFormat = "PDF", envir = new.env(), quiet = FALSE, ... )
mifScen |
|
outputDir |
|
outputFile |
|
outputFormat |
|
envir |
|
quiet |
|
... |
YAML parameters, see below. |
The value returned by rmarkdown::render().
cfgScencharacter(n) or NULL.
Paths to config.Rdata files containing the cfg object for each
scenario. The paths must be provided in the same order as mifScen.
If provided, some information gathered from these files is
shown at the beginning of the output document.
cfgDefaultcharacter(1) or NULL.
Path to default.cfg, which creates a cfg object with default
values. If provided, some information gathered from this file is
shown at the beginning of the output document.
yearsScennumeric(n).
Default: c(seq(2005, 2060, 5), seq(2070, 2100, 10)).
Years to show for scenario data.
yearsHistnumeric(n).
Default: c(seq(1960, 2020, 1), seq(2025, 2100, 5)).
Years to show for historical data.
yearsBarPlotnumeric(n).
Default: c(2010, 2030, 2050, 2100).
Years to show in bar plots of scenario data.
yearRefnumeric(1).
Default: 2020.
A reference year used to show relative values in Kaya decomposition.
regNULL or character(n).
Default: NULL.
Regions to show. NULL means all.
modelsHistExcludecharacter(n) or NULL.
Default: c().
Models in historical data to exclude.
sectionscharacter(n) or numeric(n) or NULL.
Default: "all".
Names or numbers of sections to include. For names subset of
c("00_info", "01_summary", "02_macro", "03_emissions",
"04_energy_supply", "05_energy_demand", "06_energy_services",
"07_climate", "08_sdp", "09_carbon_management", "99_further_info").
Use "all" to include all available sections.
Use NULL to not include any section
(useful in combination with parameter envir).
userSectionPathNULL or character(n).
Default: NULL.
Path to a *.Rmd-file that may be included as additional section.
mainRegcharacter(1).
Default: "World".
A region for which larger plots are shown.
figWidth, figHeightnumeric(1).
Default: 15 and 10, respectively.
Size of plots in inches.
warninglogical(1).
Default: TRUE.
Show warnings in output?
Christof Schoetz
## Not run: # Simple use. Creates PDF: compareScenariosLimes( mifScen = c("path/to/Base.mif", "path/to/NDC.mif"), outputFile = "compareScenariosLimesExample") # More complex use. Creates folder with Rmds: compareScenariosLimes( mifScen = c(ScenarioName1 = "path/to/scen1.mif", ScenarioName2 = "path/to/scen2.mif"), cfgScen = c("path/to/scen1/config.RData", "path/to/scen2/config.RData"), cfgDefault = "path/to/default.cfg", outputDir = "path/to/output", outputFormat = "Rmd", outputFile = format(Sys.time(), "compScen_%Y%m%d-%H%M%S"), warning = FALSE, sections = c(0, 2, 3, 99), userSectionPath = "path/to/myPlots.Rmd") # Use in development. Load data into global environment: compareScenariosLimes( mifScen = c("path/to/scen1.mif", "path/to/scen2.mif"), outputFile = format(Sys.time(), "cs2_load_%Y%m%d-%H%M%S"), sections = NULL, envir = globalenv()) ## End(Not run)## Not run: # Simple use. Creates PDF: compareScenariosLimes( mifScen = c("path/to/Base.mif", "path/to/NDC.mif"), outputFile = "compareScenariosLimesExample") # More complex use. Creates folder with Rmds: compareScenariosLimes( mifScen = c(ScenarioName1 = "path/to/scen1.mif", ScenarioName2 = "path/to/scen2.mif"), cfgScen = c("path/to/scen1/config.RData", "path/to/scen2/config.RData"), cfgDefault = "path/to/default.cfg", outputDir = "path/to/output", outputFormat = "Rmd", outputFile = format(Sys.time(), "compScen_%Y%m%d-%H%M%S"), warning = FALSE, sections = c(0, 2, 3, 99), userSectionPath = "path/to/myPlots.Rmd") # Use in development. Load data into global environment: compareScenariosLimes( mifScen = c("path/to/scen1.mif", "path/to/scen2.mif"), outputFile = format(Sys.time(), "cs2_load_%Y%m%d-%H%M%S"), sections = NULL, envir = globalenv()) ## End(Not run)
Read in all information from GDX file and create the *.mif reporting
convGDX2MIF( gdx, gdx_ref = NULL, file = NULL, scenario = "default", time = as.numeric(readGDX(gdx, name = "t")) )convGDX2MIF( gdx, gdx_ref = NULL, file = NULL, scenario = "default", time = as.numeric(readGDX(gdx, name = "t")) )
gdx |
a GDX as created by readGDX, or the file name of a gdx |
gdx_ref |
reference-gdx for policy costs, a GDX as created by readGDX, or the file name of a gdx |
file |
name of the mif file which will be written, if no name is provided a magpie object containing all the reporting information is returned |
scenario |
scenario name that is used in the *.mif reporting |
time |
temporal resolution of the reporting, default: c(seq(2010,2050,5)) |
Sebastian Osorio and Renato Rodrigues
## Not run: convGDX2MIF(gdx,gdx_ref,file="LIMES_generic_default.csv",scenario="default")## Not run: convGDX2MIF(gdx,gdx_ref,file="LIMES_generic_default.csv",scenario="default")
Read in all information from GDX file and create the *.mif reporting for the power generation at the time slice resolution
convGDX2MIF_tau( gdx, file = NULL, scenario = "default", time = as.numeric(readGDX(gdx, name = "t")) )convGDX2MIF_tau( gdx, file = NULL, scenario = "default", time = as.numeric(readGDX(gdx, name = "t")) )
gdx |
a GDX as created by readGDX, or the file name of a gdx |
file |
name of the mif file which will be written, if no name is provided a magpie object containing all the reporting information is returned |
scenario |
scenario name that is used in the *.mif reporting |
time |
temporal resolution of the reporting, default: c(seq(2010,2050,5)) |
Antoine Levesque
## Not run: convGDX2MIF_tau(gdx, file = "LIMES_tau_default.csv", scenario = "default") ## End(Not run)## Not run: convGDX2MIF_tau(gdx, file = "LIMES_tau_default.csv", scenario = "default") ## End(Not run)
Read in GDX and import different parameters used in convGDX2MIF.R for intermediate calculations in the reporting
importParameters(gdx)importParameters(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: importParameters(gdx)## Not run: importParameters(gdx)
Allocating years to variables that do not change over time
limesAllocateYears(var, gdx)limesAllocateYears(var, gdx)
var |
variable to be changed |
gdx |
a GDX as created by readGDX, or the file name of a gdx |
Sebastian Osorio
## Not run: limesAllocateYears(var)## Not run: limesAllocateYears(var)
Discounting variables (matrix)
limesDiscount(var, gdx)limesDiscount(var, gdx)
var |
variable to be changed |
gdx |
a GDX as created by readGDX, or the file name of a gdx |
Sebastian Osorio
## Not run: limesDiscount(var)## Not run: limesDiscount(var)
mapping of weights for the variables for global aggregation
limesInt2Ext(gdx, output, reporting_tau = FALSE, mappingPath = NULL)limesInt2Ext(gdx, output, reporting_tau = FALSE, mappingPath = NULL)
gdx |
a GDX as created by readGDX, or the file name of a gdx |
output |
variable to be changed |
reporting_tau |
boolean determining whether to generate the tau reports |
mappingPath |
path to mapping file |
Sebastian Osorio and Renato Rodrigues
Mapping limes iso 2 codes to iso 3 codes
limesMapping(var, mappingPath = NULL)limesMapping(var, mappingPath = NULL)
var |
variable to be changed |
mappingPath |
path to mapping file |
Sebastian Osorio and Renato Rodrigues
## Not run: LIMESMapping(var,mappingPath="R/mapping/mapping.csv")## Not run: LIMESMapping(var,mappingPath="R/mapping/mapping.csv")
LIMES model status of optimization
modelstat(gdx, file = NULL)modelstat(gdx, file = NULL)
gdx |
GDX file |
file |
a file name the output should be written to using write.magpie |
A MAgPIE object containing the modelstat
David Klein
## Not run: x <- modelstat(gdx) ## End(Not run)## Not run: x <- modelstat(gdx) ## End(Not run)
Read in Capacity Adequacy information from GDX file, information used in convGDX2MIF.R for the reporting
reportAdequacyContribution(gdx)reportAdequacyContribution(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the Capacity Adequacy variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportCapacity Adequacy(gdx)## Not run: reportCapacity Adequacy(gdx)
Read in annual availability factors (for nonRES) information from GDX file, information used in convGDX2MIF.R for the reporting
reportAnnualAvFactor(gdx)reportAnnualAvFactor(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the annual availability factors (for nonRES)
Sebastian Osorio, Renato Rodrigues
## Not run: reportAnnualAvFactor(gdx)## Not run: reportAnnualAvFactor(gdx)
Read in (net and gross) demand data from GDX file, information used in convGDX2MIF.R for the reporting
reportBuildings(gdx, output = NULL)reportBuildings(gdx, output = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
MAgPIE object - contains buildings module variables
Sebastian Osorio
## Not run: reportBuildings(gdx) ## End(Not run)## Not run: reportBuildings(gdx) ## End(Not run)
Read in buildtime information from GDX file, information used in convGDX2MIF.R for the reporting
reportBuildtime(gdx)reportBuildtime(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the buildtimes
Sebastian Osorio, Renato Rodrigues
## Not run: reportBuildtime(gdx)## Not run: reportBuildtime(gdx)
Read in capacity information from GDX file, information used in convGDX2MIF.R for the reporting
reportCapacity(gdx)reportCapacity(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportCapacity(gdx)## Not run: reportCapacity(gdx)
Read in capacity additions from GDX file, information used in convGDX2MIF.R for the reporting
reportCapacityAdditions(gdx)reportCapacityAdditions(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio
## Not run: reportCapacityAdditions(gdx)## Not run: reportCapacityAdditions(gdx)
Read in fuel costs information from GDX file, information used in convGDX2MIF.R for the reporting
reportCapitalCosts(gdx)reportCapitalCosts(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the fuel costs
Sebastian Osorio
## Not run: reportFuelCosts(gdx)## Not run: reportFuelCosts(gdx)
Read in carbon sequestred data from GDX file, information used in convGDX2MIF.R for the reporting
reportCarbonSequestration(gdx)reportCarbonSequestration(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportCarbonSequestration(gdx)## Not run: reportCarbonSequestration(gdx)
Read in exogenous co2 prices and marginal values from GDX file, information used in convGDX2MIF.R for the reporting
reportCO2Price(gdx)reportCO2Price(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportCO2Price(gdx)## Not run: reportCO2Price(gdx)
Read in electricity curtailment data from GDX file, information used in convGDX2MIF.R for the reporting
reportCurtailment(gdx)reportCurtailment(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the curtailment
Sebastian Osorio
## Not run: reportCurtailment(gdx)## Not run: reportCurtailment(gdx)
Read in (net and gross) demand data from GDX file, information used in convGDX2MIF.R for the reporting
reportDemand(gdx, output = NULL, reporting_tau = FALSE)reportDemand(gdx, output = NULL, reporting_tau = FALSE)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
reporting_tau |
boolean determining whether to generate the tau reports reporting at the time slice level (TRUE) or at the yearly level (FALSE, default) |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportDemand(gdx, output = NULL) ## End(Not run)## Not run: reportDemand(gdx, output = NULL) ## End(Not run)
Read in Disinvestment from GDX file, information used in convGDX2MIF.R for the reporting
reportDisinvestments(gdx)reportDisinvestments(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio
## Not run: reportCapacityAdditions(gdx)## Not run: reportCapacityAdditions(gdx)
Read in electrical efficiency information from GDX file, information used in convGDX2MIF.R for the reporting
reportElectricalEfficiency(gdx)reportElectricalEfficiency(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the electrical efficiency
Sebastian Osorio, Renato Rodrigues
## Not run: reportElectricalEfficiency(gdx)## Not run: reportElectricalEfficiency(gdx)
Read in electricity prices information from GDX file, information used in convGDX2MIF.R for the reporting
reportElectricityPrices(gdx, reporting_tau = FALSE)reportElectricityPrices(gdx, reporting_tau = FALSE)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
reporting_tau |
boolean determining whether to generate the tau report |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportElectricityPrices(gdx)## Not run: reportElectricityPrices(gdx)
Read in emissions data from GDX file, information used in convGDX2MIF.R for the reporting
reportEmissions(gdx, output = NULL)reportEmissions(gdx, output = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
MAgPIE object - contains the emission variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportEmissions(gdx)## Not run: reportEmissions(gdx)
Read in data that only exists at EU ETS level, information used in convGDX2MIF.R for the reporting
reportEUETSvars(gdx, output = NULL)reportEUETSvars(gdx, output = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
MAgPIE object - contains the emission variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportEUETSvars(gdx)## Not run: reportEUETSvars(gdx)
Read in electricity exchange data from GDX file, information used in convGDX2MIF.R for the reporting
reportExchange(gdx)reportExchange(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportExchange(gdx)## Not run: reportExchange(gdx)
Create fictitious variables to ensure symetry of the magpie object, information used in convGDX2MIF.R for the reporting
reportFictitiousVars(gdx, output = NULL)reportFictitiousVars(gdx, output = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
MAgPIE object - contains the emission variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportFictitiousVars(gdx)## Not run: reportFictitiousVars(gdx)
Read in fuel costs information from GDX file, information used in convGDX2MIF.R for the reporting
reportFuelCosts(gdx)reportFuelCosts(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the fuel costs
Sebastian Osorio, Renato Rodrigues
## Not run: reportFuelCosts(gdx)## Not run: reportFuelCosts(gdx)
Read in electricity generation data from GDX file, information used in convGDX2MIF.R for the reporting
reportGeneration(gdx, reporting_tau = FALSE)reportGeneration(gdx, reporting_tau = FALSE)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
reporting_tau |
boolean determining whether to generate the tau report reporting at the time slice level (TRUE) or at the yearly level (FALSE, default) |
MAgPIE object - contains the Generation variables
Sebastian Osorio, Renato Rodrigues, Antoine Levesque
## Not run: reportGeneration(gdx) ## End(Not run)## Not run: reportGeneration(gdx) ## End(Not run)
Read in max availability factors per hour (for nonRES) information from GDX file, information used in convGDX2MIF.R for the reporting
reportHourAvFactor(gdx)reportHourAvFactor(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the max availability factors per hour (for nonRES)
Sebastian Osorio, Renato Rodrigues
## Not run: reportHourAvFactor(gdx)## Not run: reportHourAvFactor(gdx)
Read in hydrogen-related data from GDX file, information used in convGDX2MIF.R for the reporting
reportHydrogen(gdx, output = NULL)reportHydrogen(gdx, output = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions reporting at the time slice level (TRUE) or at the yearly level (FALSE, default) |
MAgPIE object - contains the Generation variables
Sebastian Osorio
## Not run: reportHydrogen(gdx) ## End(Not run)## Not run: reportHydrogen(gdx) ## End(Not run)
Read in emissions data from GDX file, information used in convGDX2MIF.R for the reporting
reportIndustryEmissions(gdx, output = NULL)reportIndustryEmissions(gdx, output = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
MAgPIE object - contains the emission variables
Sebastian Osorio
## Not run: reportIndustryEmissions(gdx,output=NULL)## Not run: reportIndustryEmissions(gdx,output=NULL)
Read in emissions data from GDX file, information used in convGDX2MIF.R for the reporting
reportIndustryModule(gdx)reportIndustryModule(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the emission variables
Sebastian Osorio
## Not run: reportIndustryModule(gdx)## Not run: reportIndustryModule(gdx)
Read in availability factors information from GDX file, information used in convGDX2MIF.R for the reporting
reportInput(gdx, mappingPath = NULL)reportInput(gdx, mappingPath = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
mappingPath |
path to mapping file |
MAgPIE object - contains the availability factors
Sebastian Osorio, Renato Rodrigues
## Not run: reportInput(gdx)## Not run: reportInput(gdx)
Read in investment costs information from GDX file, information used in convGDX2MIF.R for the reporting
reportInvestmentCosts(gdx)reportInvestmentCosts(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the investment costs
Sebastian Osorio, Renato Rodrigues
## Not run: reportInvestmentCosts(gdx)## Not run: reportInvestmentCosts(gdx)
Read in lifetime information from GDX file, information used in convGDX2MIF.R for the reporting
reportLifetime(gdx)reportLifetime(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the lifetimes
Sebastian Osorio, Renato Rodrigues
## Not run: reportLifetime(gdx)## Not run: reportLifetime(gdx)
Read in electricity generation data from GDX file, information used in convGDX2MIF.R for the reporting
reportLoadFactor(gdx, output = NULL, reporting_tau = FALSE)reportLoadFactor(gdx, output = NULL, reporting_tau = FALSE)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
reporting_tau |
boolean determining whether to generate the tau report |
MAgPIE object - contains the capacity variables
Sebastian Osorio
## Not run: reportLoadFactor(gdx)## Not run: reportLoadFactor(gdx)
Read in emissions data from GDX file, information used in convGDX2MIF.R for the reporting
reportMSR(gdx)reportMSR(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the emission variables
Sebastian Osorio
## Not run: reportEmissions(gdx)## Not run: reportEmissions(gdx)
Read in availability factors information from GDX file, information used in convGDX2MIF.R for the reporting
reportNuren(gdx)reportNuren(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the availability factors
Sebastian Osorio, Renato Rodrigues
## Not run: reportNuren(gdx)## Not run: reportNuren(gdx)
Read in Fixed O&M costs information from GDX file, information used in convGDX2MIF.R for the reporting
reportOMF(gdx)reportOMF(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the Fixed O&M costs
Sebastian Osorio, Renato Rodrigues
## Not run: reportOMF(gdx)## Not run: reportOMF(gdx)
Read in Variable O&M information from GDX file, information used in convGDX2MIF.R for the reporting
reportOMV(gdx)reportOMV(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the Variable O&M
Sebastian Osorio, Renato Rodrigues
## Not run: reportOMV(gdx)## Not run: reportOMV(gdx)
Read in emissions data from GDX file, information used in convGDX2MIF.R for the reporting
reportOtherEUETSsector(gdx)reportOtherEUETSsector(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the emission variables
Sebastian Osorio
## Not run: reportOtherEUETSsector(gdx)## Not run: reportOtherEUETSsector(gdx)
Read in gross demand data from GDX file, information used in convGDX2MIF.R for the reporting
reportPeakDemand(gdx)reportPeakDemand(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportPeakDemand(gdx)## Not run: reportPeakDemand(gdx)
Read in primary energy data from GDX file, information used in convGDX2MIF.R for the reporting
reportPrimaryEnergy(gdx)reportPrimaryEnergy(gdx)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
MAgPIE object - contains the capacity variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportPrimaryEnergy(gdx)## Not run: reportPrimaryEnergy(gdx)
Read in electricity generation data from GDX file, information used in convGDX2MIF.R for the reporting
reportTotalSystemCosts(gdx, output = NULL)reportTotalSystemCosts(gdx, output = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
MAgPIE object - contains the Generation variables
Sebastian Osorio, Renato Rodrigues
## Not run: reportTotalSystemCosts(gdx)## Not run: reportTotalSystemCosts(gdx)
Read in data that only exists at UK ETS level, information used in convGDX2MIF.R for the reporting
reportUKETSvars(gdx, output = NULL)reportUKETSvars(gdx, output = NULL)
gdx |
a GDX object as created by readGDX, or the path to a gdx |
output |
a magpie object containing all needed variables generated by other report*.R functions |
MAgPIE object - contains the emission variables
Sebastian Osorio
## Not run: reportUKETSvars(gdx)## Not run: reportUKETSvars(gdx)